import { shallowEqual } from './utils';
export function bindStore(store) {
    const dispatch = store.dispatch.bind(store);
    const getState = store.getState.bind(store);
    const subscribe = store.subscribe.bind(store);
    const connect = (mapStateToProps, propsChangedHandler) => {
        // initial props
        let props = mapStateToProps(store.getState());
        propsChangedHandler({
            newProps: props,
            prevProps: null,
            getState,
            dispatch,
        });
        return store.subscribe(() => {
            const newProps = mapStateToProps(store.getState());
            // shallow compare
            if (shallowEqual(newProps, props)) {
                return;
            }
            const prevProps = props;
            props = newProps;
            propsChangedHandler({
                newProps,
                prevProps,
                getState,
                dispatch,
            });
        });
    };
    return {
        dispatch,
        getState,
        subscribe,
        connect,
    };
}
